@@ -1,5 +1,9 @@
 '''
 A collection of functions which do some of the core work of the HMF calculation.
+
+The routines here could be made more 'elegant' by taking `MassFunction` or 
+`Transfer` objects as arguments, but we keep them simple for the sake of 
+flexibility.
 '''
 
 #===============================================================================
@@ -7,80 +11,21 @@ A collection of functions which do some of the core work of the HMF calculation.
 #===============================================================================
 import numpy as np
 import scipy.integrate as intg
-import pycamb
 import collections
-import cosmolopy.perturbation as pert
 import cosmolopy.distance as cdist
-from scipy.interpolate import InterpolatedUnivariateSpline as spline
 
 #===============================================================================
 # Functions
 #===============================================================================
-def get_transfer(transfer_file, cosmo_params, transfer_fit,
-                 camb_options=None, k_bounds=None):
-    """
-    Calculate a transfer function.
-    
-    Uses either CAMB or the EH transfer functions.
-    
-    Parameters
-    ----------
-    transfer_file : `str` or ``None``
-        A full or relative path to a file containing the transfer function.
-        The file must be in the same format as CAMB transfer function output,
-        ie. 7 columns, the first being k/h and the 7th being the total transfer.
-        
-    cosmo_params : `Cosmology` instance
-        An instance of the `Cosmology` class from this package. Contains all 
-        cosmological parameters.
-        
-    transfer_fit : `str` {``"CAMB"``,``"EH"``}
-        A string identifier specifying which transfer function fit to use.
-        
-    camb_options : `dict`, default ``None``
-        A dictionary of options to send to the `pycamb.transfers` routine. Does
-        not include cosmological parameters.
-        
-    k_bounds : sequence, len=2
-        Minimum and maximum bounds on *k/h*. Only used for the EH transfer fit.
-        
-    Returns
-    -------
-    T : array_like
-        An array with the first column containing values of ln*(k/h)* and the second
-        the natural log of the total transfer function.
-    """
-    # If no transfer file uploaded, but it was custom, execute CAMB
-    if transfer_file is None:
-        if transfer_fit == "CAMB":
-            cdict = dict(cosmo_params.pycamb_dict(),
-                         **camb_options)
-            k, T, sig8 = pycamb.transfers(**cdict)
-            T = np.log(T[[0, 6], :, 0])
-            del sig8, k
-        elif transfer_fit == "EH":
-            k = np.exp(np.linspace(np.log(k_bounds[0]), np.log(k_bounds[1]), 250))
-            # Since the function natively calculates the transfer based on k in Mpc^-1,
-            # we need to multiply by h.
-            t, T = pert.transfer_function_EH(k * cosmo_params.h,
-                                             **cosmo_params.cosmolopy_dict())
-            T = np.vstack((np.log(k), np.log(T)))
-            del t
-    else:
-        # Import the transfer file
-        transfer = np.log(np.genfromtxt(transfer_file)[:, [0, 6]].T)
-        k = transfer[0, :]
-        T = transfer[1, :]
-    return T
-
 def check_kr(min_m, max_m, mean_dens, mink, maxk):
     """
     Check the bounds of the product of k*r
     
     If the bounds are not high/low enough, then there can be information loss
-    in the calculation of the mass variance.
+    in the calculation of the mass variance. This routine returns a warning
+    indicating the necessary adjustment for requisite accuracy.
     
-    See http://arxiv.org/abs/1306.6721 
+    See http://arxiv.org/abs/1306.6721 for details. 
     """
     # Define mass from radius function
     def M(r):
@@ -116,50 +61,9 @@ If it is not, then the mass variance could be inaccurate.
 
     return error1, error2
 
-def interpolate_transfer(k, transfer, tol=0.01):
-    """
-    Interpolate the given transfer function
-    
-    Parameters
-    ----------
-    k : array_like
-        Value of lnk
-        
-    transfer : array_like
-        values of lnT
-        
-    tol : float, default 0.01
-        The routine performs a check that at low-k the slope asymptotes to a 
-        slope of zero. If this is not true the transfer function is cut when the 
-        slope is out by tol. 
-              
-    Notes
-    -----
-    Interpolation is linear as we may have to extrapolate.
-    """
-    # Unfortunately it looks like there's a turn-up at low-k for some CAMB
-    # transfers which makes the extrapolation silly.
-    # If this is the case, we start when it is nice.
-
-    start = 0
-    for i in range(len(k) - 1):
-        if abs((transfer[i + 1] - transfer[i]) / (k[i + 1] - k[i])) < tol:
-            start = i
-            break
-    if start > 0:
-        transfer = transfer[start:-1]
-        k = k[start:-1]
-        spline_order = 1
-    else:
-        spline_order = 1
-
-    transfer_function = spline(k, transfer, k=spline_order)
-
-    return transfer_function
-
 def normalize(norm_sigma_8, unn_power, lnk, mean_dens):
     """
-    Normalize the power spectrum to a given sigma_8
+    Normalize the power spectrum to a given :math:`\sigma_8`
     
     Parameters
     ----------
@@ -200,7 +104,7 @@ def normalize(norm_sigma_8, unn_power, lnk, mean_dens):
 
 def mass_variance(M, power, lnk, mean_dens):
     """
-    Calculate the Mass Variance of M using the top-hat window function.
+    Calculate the mass variance, :math:`\sigma(M)` using the top-hat window function.
     
     Parameters
     ----------
@@ -218,7 +122,7 @@ def mass_variance(M, power, lnk, mean_dens):
         Mean density of the Universe
         
     Returns
-    sigma : array_like (len(M))
+    sigma : array_like ( ``len=len(M)`` )
         The mass variance at ``M``
         
     """
@@ -260,11 +164,8 @@ def top_hat_window(M, lnk, mean_dens):
         The square of the top-hat window function in fourier space 
     """
 
-    # Calculate the factor kR, minding to un-log k before use.
     kR = np.exp(lnk) * mass_to_radius(M, mean_dens)
     W_squared = (3 * (np.sin(kR) / kR ** 3 - np.cos(kR) / kR ** 2)) ** 2
-    W_squared[kR < 0.01] = 1.0
-
     return W_squared
 
 
@@ -285,41 +186,41 @@ def mass_to_radius(M, mean_dens):
     R : float or array of floats
         The corresponding radii to M
     
-    Notes
-    -----
-    The units of ``M`` don't matter as long as they are consistent with 
-    ``mean_dens``.
+    .. note :: The units of ``M`` don't matter as long as they are consistent with 
+            ``mean_dens``.
     """
     return (3.*M / (4.*np.pi * mean_dens)) ** (1. / 3.)
-
-def radius_to_mass(R, mean_dens):
-    """
-    Calculates mass of a region of space from its radius
-    
-    Parameters
-    ----------
-    R : float or array of floats
-        Radii
-        
-    mean_dens : float
-        The mean density of the universe
-        
-    Returns
-    ------
-    M : float or array of floats
-        The corresponding masses in R
-    
-    Notes
-    -----
-    The units of ``R`` don't matter as long as they are consistent with 
-    ``mean_dens``.
-    """
-    return 4 * np.pi * R ** 3 * mean_dens / 3
+#
+# def radius_to_mass(R, mean_dens):
+#     """
+#     Calculates mass of a region of space from its radius
+#
+#     Parameters
+#     ----------
+#     R : float or array of floats
+#         Radii
+#
+#     mean_dens : float
+#         The mean density of the universe
+#
+#     Returns
+#     ------
+#     M : float or array of floats
+#         The corresponding masses in R
+#
+#     Notes
+#     -----
+#     The units of ``R`` don't matter as long as they are consistent with
+#     ``mean_dens``.
+#     """
+#     return 4 * np.pi * R ** 3 * mean_dens / 3
 
 def wdm_transfer(m_x, power_cdm, lnk, h, omegac):
     """
     Transform a CDM Power Spectrum into WDM.
     
+    Formula from Bode et. al. 2001 eq. A9
+    
     Parameters
     ----------
     m_x : float
@@ -343,9 +244,6 @@ def wdm_transfer(m_x, power_cdm, lnk, h, omegac):
     power_wdm : array
         The normalised WDM power spectrum at ``lnk``.
         
-    Notes
-    -----
-    Formula from Bode et. al. 2001 eq. A9
     """
     g_x = 1.5
     nu = 1.12
@@ -357,8 +255,8 @@ def wdm_transfer(m_x, power_cdm, lnk, h, omegac):
     return power_cdm + 2 * np.log(transfer)
 
 def dlnsdlnm(M, sigma, power, lnk, mean_dens):
-    """
-    Calculate the derivative of log sigma with log M
+    r"""
+    Calculate :math:\frac{d \ln(\sigma)}{d \ln M}`
     
     Parameters
     ----------
@@ -369,7 +267,7 @@ def dlnsdlnm(M, sigma, power, lnk, mean_dens):
         Mass variance at M
 
     power : array
-        The power spectrum at ``lnk``
+        The logarithmic power spectrum at ``lnk``
         
     lnk : array
         The wavenumbers *k/h* corresponding to the power
@@ -441,7 +339,7 @@ def d_plus(z, cosmo):
     z : float
         The redshift
         
-    cosmo : ``Cosmology()`` object
+    cosmo : ``hmf.cosmo.Cosmology()`` object
         Cosmological parameters 
     
     Returns
@@ -470,7 +368,7 @@ def growth_factor(z, cosmo):
     z : float
         The redshift
         
-    cosmo : ``Cosmology()`` object
+    cosmo : ``hmf.cosmo.Cosmology()`` object
         Cosmological parameters 
     
     Returns
